Pure Python GeoIP API
=====================

This library is based on `Maxmind's GeoIP C API <https://github.com/maxmind/geoip-api-c>`__.

Tested with Python version 2.6, 2.7, 3.2 and 3.3.

|Build Status| |Coverage Status| |Downloads|

Installation
------------

You can easily install pygeoip from PyPi.

.. code:: python

    pip install pygeoip

Issues and Contribution
-----------------------

Bug reports are done by `creating an issue on
Github <https://github.com/appliedsec/pygeoip/issues>`__. If you want to
contribute you can always `create a pull
request <https://github.com/appliedsec/pygeoip/pulls>`__ for discussion
and code submission.

Documentation
-------------

.. toctree::
   :maxdepth: 1

   getting-started
   supported-databases
   api-reference

For more information, `check out the documentation <http://pygeoip.readthedocs.org/>`__ over at Read the Docs.

.. |Build Status| image:: https://api.travis-ci.org/appliedsec/pygeoip.png?branch=master
	:target: https://travis-ci.org/appliedsec/pygeoip
.. |Coverage Status| image:: https://coveralls.io/repos/appliedsec/pygeoip/badge.png
	:target: https://coveralls.io/r/appliedsec/pygeoip
.. |Downloads| image:: https://pypip.in/d/pygeoip/badge.png
	:target: https://crate.io/packages/pygeoip
